/*
 * Copyright 2014-2017 ISP RAS (http://www.ispras.ru)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase;

import ru.ispras.fortress.util.InvariantChecks;

import java.util.Collections;
import java.util.Map;

public final class TestData {
  public static final String DEFAULT_ID = "default";
  public static final TestData EMPTY = new TestData(Collections.<String, Object>emptyMap());

  private final String id;
  private final Map<String, Object> bindings;

  public TestData(final Map<String, Object> bindings) {
    this(DEFAULT_ID, bindings);
  }

  public TestData(final String id, final Map<String, Object> bindings) {
    InvariantChecks.checkNotNull(id);
    InvariantChecks.checkNotNull(bindings);

    this.id = id;
    this.bindings = bindings;
  }

  public String getId() {
    return id;
  }

  public Map<String, Object> getBindings() {
    return bindings;
  }

  public boolean isEmpty() {
    return bindings.isEmpty();
  }

  @Override
  public String toString() {
    return String.format("TestData [id=%s, bindings=%s]", id, bindings);
  }
}
